==> selene-0.2.0.tar.gz: lib/src/core/client.dart <==
part of selene;

/// The base class for all Selene clients.
class Client {
  /// The logger of this client.
  final Logger _log = new Logger('Selene-Client');

  /// Whether to warn (through the logger) if the token type is not in [validTypes].
  final bool warnOnBadType = true;

  /// A list of acceptable token types.
  ///
  /// Client will warn if [warnOnBadType] is true.
  final List<String> validTypes = ['Bot', 'Bearer'];

  /// The current event dispatcher.
  _Dispatcher dispatcher;

  /// The current REST API implementation.
  RestBase _rest;

  /// The current WebSocket API implementation.
  WSBase _ws;

  /// The current cache for all Discord entities.
  EntityCache cache;

  /// Initializes this client.
  Client({RestBase rest, WSBase ws}) {
    _rest = rest ?? new _RestImpl();
    _ws = ws ?? new _WebSocketImpl(this);
    dispatcher = new _Dispatcher(this);
    cache = new EntityCache(this);
  }

  /// The current logged-in client user.
  ///
  /// Will be null if the client hasn't authenticated.
  User get self => cache.self;

  /// Authenticates this Discord client using the provided token and type.
  ///
  /// Must be invoked after [Client.start] has been invoked to ensure a successful connection.
  Future login(String token, {String type = 'Bot'}) async {
    if (token == null || token.isEmpty)
      throw new ArgumentError('Token provided must be not null or empty');
    if (type == null ||
        type.isEmpty ||
        !['Bot', '', 'Bearer', 'Webhook'].contains(type))
      throw new ArgumentError('Provided token type is invalid, null or empty');

    if (!validTypes.contains(type) && warnOnBadType)
      _log.warning(
          'Using a token type that is not Bot or Bearer is not supported and may get you banned from the Discord API.');

    _rest.login(token, type: type);
    await _ws.login(token, type: type);
  }

  /// Opens the WebSocket connection.
  ///
  /// After this, [Client.login] should be invoked to authorize with Discord.
  Future start() => _ws.start(false);

  /// Closes the WebSocket connection.
  ///
  /// The WebSocket connection will be closed, and calling anything on the WebSocket will now throw an exception.
  Future stop() => _ws.stop();
}

==> selene-0.2.1.tar.gz: lib/src/core/client.dart <==
part of selene;

/// The base class for all Selene clients.
class Client {
  /// The logger of this client.
  final Logger _log = new Logger('Selene-Client');

  /// Whether to warn (through the logger) if the token type is not in [validTypes].
  final bool warnOnBadType = true;

  /// A list of acceptable token types.
  ///
  /// Client will warn if [warnOnBadType] is true.
  final List<String> validTypes = ['Bot', 'Bearer'];

  /// The current event dispatcher.
  Dispatcher dispatcher;

  /// The current REST API implementation.
  RestBase _rest;

  /// The current WebSocket API implementation.
  WSBase _ws;

  /// The current cache for all Discord entities.
  EntityCache cache;

  /// Initializes this client.
  Client({RestBase rest, WSBase ws}) {
    _rest = rest ?? new _RestImpl();
    _ws = ws ?? new _WebSocketImpl(this);
    dispatcher = new Dispatcher(this);
    cache = new EntityCache(this);
  }

  /// The current logged-in client user.
  ///
  /// Will be null if the client hasn't authenticated.
  User get self => cache.self;

  /// Authenticates this Discord client using the provided token and type.
  ///
  /// Must be invoked after [Client.start] has been invoked to ensure a successful connection.
  Future login(String token, {String type = 'Bot'}) async {
    if (token == null || token.isEmpty)
      throw new ArgumentError('Token provided must be not null or empty');
    if (type == null ||
        type.isEmpty ||
        !['Bot', '', 'Bearer', 'Webhook'].contains(type))
      throw new ArgumentError('Provided token type is invalid, null or empty');

    if (!validTypes.contains(type) && warnOnBadType)
      _log.warning(
          'Using a token type that is not Bot or Bearer is not supported and may get you banned from the Discord API.');

    _rest.login(token, type: type);
    await _ws.login(token, type: type);
  }

  /// Opens the WebSocket connection.
  ///
  /// After this, [Client.login] should be invoked to authorize with Discord.
  Future start() => _ws.start(false);

  /// Closes the WebSocket connection.
  ///
  /// The WebSocket connection will be closed, and calling anything on the WebSocket will now throw an exception.
  Future stop() => _ws.stop();
}
